@@ -10,17 +10,17 @@ die () {
 
 cd /tmp/ || die "Can't chdir to /tmp/ ."
 
-if [ ! -r kernel-3.10.0-229.11.1.el7.src.rpm ]
+if [ ! -r kernel-3.10.0-327.4.5.el7.src.rpm ]
 then
-    wget http://vault.centos.org/centos/7/updates/Source/SPackages/kernel-3.10.0-229.11.1.el7.src.rpm || die "Can't download source package."
+    wget http://vault.centos.org/centos/7/updates/Source/SPackages/kernel-3.10.0-327.4.5.el7.src.rpm || die "Can't download source package."
 fi
-LANG=C rpm --checksig kernel-3.10.0-229.11.1.el7.src.rpm | grep -F ': rsa sha1 (md5) pgp md5 OK' || die "Can't verify signature."
-rpm -ivh kernel-3.10.0-229.11.1.el7.src.rpm || die "Can't install source package."
+LANG=C rpm --checksig kernel-3.10.0-327.4.5.el7.src.rpm | grep -F ': rsa sha1 (md5) pgp md5 OK' || die "Can't verify signature."
+rpm -ivh kernel-3.10.0-327.4.5.el7.src.rpm || die "Can't install source package."
 
 cd ~/rpmbuild/SOURCES/ || die "Can't chdir to ~/rpmbuild/SOURCES/ ."
-if [ ! -r caitsith-patch-0.1-20150806.tar.gz ]
+if [ ! -r caitsith-patch-0.1-20160214.tar.gz ]
 then
-    wget -O caitsith-patch-0.1-20150806.tar.gz 'http://sourceforge.jp/frs/redir.php?f=/caitsith/55464/caitsith-patch-0.1-20150806.tar.gz' || die "Can't download patch."
+    wget -O caitsith-patch-0.1-20160214.tar.gz 'http://osdn.jp/frs/redir.php?f=/caitsith/55464/caitsith-patch-0.1-20160214.tar.gz' || die "Can't download patch."
 fi
 
 cd ~/rpmbuild/SPECS/ || die "Can't chdir to ~/rpmbuild/SPECS/ ."
@@ -37,7 +37,7 @@ patch << "EOF" || die "Can't patch spec file."
  
  # For a kernel released for public testing, released_kernel should be 1.
  # For internal testing builds during development, it should be 0.
-@@ -275,7 +275,7 @@
+@@ -277,7 +277,7 @@
  AutoProv: yes\
  %{nil}
  
@@ -46,7 +46,7 @@ patch << "EOF" || die "Can't patch spec file."
  Group: System Environment/Kernel
  License: GPLv2
  URL: http://www.kernel.org/
-@@ -563,13 +563,13 @@
+@@ -574,13 +574,13 @@
  %package %{?1:%{1}-}devel\
  Summary: Development package for building kernel modules to match the %{?2:%{2} }kernel\
  Group: System Environment/Kernel\
@@ -64,18 +64,18 @@ patch << "EOF" || die "Can't patch spec file."
  This package provides kernel headers and makefiles sufficient to build modules\
  against the %{?2:%{2} }kernel package.\
  %{nil}
-@@ -681,6 +681,10 @@
+@@ -692,6 +692,10 @@
  ApplyOptionalPatch debrand-rh_taint.patch
  ApplyOptionalPatch debrand-rh-i686-cpu.patch
  
 +# CaitSith
-+tar -zxf %_sourcedir/caitsith-patch-0.1-20150806.tar.gz
++tar -zxf %_sourcedir/caitsith-patch-0.1-20160214.tar.gz
 +sed -i -e 's/CCSECURITY/CAITSITH/g' -e 's/ccsecurity/caitsith/g' -e 's/ccs_domain_info/cs_domain_info/g' -e 's/ccs_flags/cs_flags/g' patches/ccs-patch-*.diff
 +patch -sp1 < patches/ccs-patch-3.10-centos-7.diff
  # Any further pre-build tree manipulations happen here.
  
  chmod +x scripts/checkpatch.pl
-@@ -711,6 +715,17 @@
+@@ -730,6 +734,17 @@
  for i in *.config
  do
    mv $i .config
