@@ -38,9 +38,9 @@ apt-get -y install wget zlib1g-dev debian-keyring
 # Download CaitSith patches.
 mkdir -p /root/rpmbuild/SOURCES/
 cd /root/rpmbuild/SOURCES/ || die "Can't chdir to /root/rpmbuild/SOURCES/ ."
-if [ ! -r caitsith-patch-0.1-20150806.tar.gz ]
+if [ ! -r caitsith-patch-0.1-20160214.tar.gz ]
 then
-    wget -O caitsith-patch-0.1-20150806.tar.gz 'http://sourceforge.jp/frs/redir.php?f=/caitsith/55464/caitsith-patch-0.1-20150806.tar.gz' || die "Can't download patch."
+    wget -O caitsith-patch-0.1-20160214.tar.gz 'http://osdn.jp/frs/redir.php?f=/caitsith/55464/caitsith-patch-0.1-20160214.tar.gz' || die "Can't download patch."
 fi
 
 # Install kernel source packages.
@@ -52,7 +52,7 @@ tar -jxf linux-source-2.6.32.tar.bz2
 
 # Apply patches and create kernel config.
 cd linux-source-2.6.32 || die "Can't chdir to linux-source-2.6.32/ ."
-tar -zxf /root/rpmbuild/SOURCES/caitsith-patch-0.1-20150806.tar.gz || die "Can't extract patch."
+tar -zxf /root/rpmbuild/SOURCES/caitsith-patch-0.1-20160214.tar.gz || die "Can't extract patch."
 sed -i -e 's/CCSECURITY/CAITSITH/g' -e 's/ccsecurity/caitsith/g' -e 's/ccs_domain_info/cs_domain_info/g' -e 's/ccs_flags/cs_flags/g' patches/ccs-patch-*.diff
 patch -p1 < patches/ccs-patch-2.6.32-debian-squeeze.diff || die "Can't apply patch."
 cat /boot/config-2.6.32-5-686 config.caitsith > .config || die "Can't create config."
