@@ -10,17 +10,17 @@ die () {
 
 cd /tmp/ || die "Can't chdir to /tmp/ ."
 
-if [ ! -r kernel-3.4.108-2vl6.src.rpm ]
+if [ ! -r kernel-3.4.110-2vl6.src.rpm ]
 then
-    wget http://updates.vinelinux.org/Vine-6.3/updates/SRPMS/kernel-3.4.108-2vl6.src.rpm || die "Can't download source package."
+    wget http://updates.vinelinux.org/Vine-6.3/updates/SRPMS/kernel-3.4.110-2vl6.src.rpm || die "Can't download source package."
 fi
-LANG=C rpm --checksig kernel-3.4.108-2vl6.src.rpm | grep -F ': (sha1) dsa sha1 md5 gpg OK' || die "Can't verify signature."
-rpm -ivh kernel-3.4.108-2vl6.src.rpm || die "Can't install source package."
+LANG=C rpm --checksig kernel-3.4.110-2vl6.src.rpm | grep -F ': (sha1) dsa sha1 md5 gpg OK' || die "Can't verify signature."
+rpm -ivh kernel-3.4.110-2vl6.src.rpm || die "Can't install source package."
 
 cd /root/rpm/SOURCES/ || die "Can't chdir to /root/rpm/SOURCES/ ."
-if [ ! -r caitsith-patch-0.1-20150806.tar.gz ]
+if [ ! -r caitsith-patch-0.1-20160214.tar.gz ]
 then
-    wget -O caitsith-patch-0.1-20150806.tar.gz 'http://sourceforge.jp/frs/redir.php?f=/caitsith/55464/caitsith-patch-0.1-20150806.tar.gz' || die "Can't download patch."
+    wget -O caitsith-patch-0.1-20160214.tar.gz 'http://osdn.jp/frs/redir.php?f=/caitsith/55464/caitsith-patch-0.1-20160214.tar.gz' || die "Can't download patch."
 fi
 
 cd /tmp/ || die "Can't chdir to /tmp/ ."
@@ -29,7 +29,7 @@ patch << "EOF" || die "Can't patch spec file."
 --- kernel34-vl.spec
 +++ kernel34-vl.spec
 @@ -34,7 +34,7 @@
- %define patchlevel 108
+ %define patchlevel 110
  %define kversion 3.%{sublevel}
  %define rpmversion 3.%{sublevel}.%{patchlevel}
 -%define release 2%{?_dist_release}
@@ -56,18 +56,18 @@ patch << "EOF" || die "Can't patch spec file."
  Group: System Environment/Kernel
  License: GPLv2
  Version: %{rpmversion}
-@@ -725,6 +728,10 @@
+@@ -741,6 +744,10 @@
  
  # END OF PATCH APPLICATIONS
  
 +# CaitSith
-+tar -zxf %_sourcedir/caitsith-patch-0.1-20150806.tar.gz
++tar -zxf %_sourcedir/caitsith-patch-0.1-20160214.tar.gz
 +sed -i -e 's/CCSECURITY/CAITSITH/g' -e 's/ccsecurity/caitsith/g' -e 's/ccs_domain_info/cs_domain_info/g' -e 's/ccs_flags/cs_flags/g' patches/ccs-patch-*.diff
 +patch -sp1 < patches/ccs-patch-3.4-vine-linux-6.diff
  cp %{SOURCE10} Documentation/
  
  # put Vine logo
-@@ -743,6 +750,9 @@
+@@ -759,6 +766,9 @@
  for i in *.config
  do 
  	mv $i .config 
