@@ -439,7 +439,7 @@ static int cs_inode_setattr(struct dentry *dentry, struct vfsmount *mnt,
 			    struct iattr *attr)
 {
 	int rc = 0;
-	struct path path = { mnt, dentry };
+	struct path path = { .mnt = mnt, .dentry = dentry };
 	if (attr->ia_valid & ATTR_UID)
 		rc = cs_chown_permission(&path, attr->ia_uid, -1);
 	if (!rc && (attr->ia_valid & ATTR_GID))
@@ -464,7 +464,7 @@ static int cs_inode_setattr(struct dentry *dentry, struct vfsmount *mnt,
  */
 static int cs_inode_getattr(struct vfsmount *mnt, struct dentry *dentry)
 {
-	struct path path = { mnt, dentry };
+	struct path path = { .mnt = mnt, .dentry = dentry };
 	int rc = cs_getattr_permission(&path);
 	if (rc)
 		return rc;
@@ -486,7 +486,7 @@ static int cs_inode_getattr(struct vfsmount *mnt, struct dentry *dentry)
 static int cs_inode_mknod(struct inode *dir, struct dentry *dentry,
 			  struct vfsmount *mnt, int mode, dev_t dev)
 {
-	struct path path = { mnt, dentry };
+	struct path path = { .mnt = mnt, .dentry = dentry };
 	int rc = cs_mknod_permission(&path, mode, dev);
 	if (rc)
 		return rc;
@@ -507,7 +507,7 @@ static int cs_inode_mknod(struct inode *dir, struct dentry *dentry,
 static int cs_inode_mkdir(struct inode *dir, struct dentry *dentry,
 			  struct vfsmount *mnt, int mode)
 {
-	struct path path = { mnt, dentry };
+	struct path path = { .mnt = mnt, .dentry = dentry };
 	int rc = cs_mkdir_permission(&path, mode);
 	if (rc)
 		return rc;
@@ -527,7 +527,7 @@ static int cs_inode_mkdir(struct inode *dir, struct dentry *dentry,
 static int cs_inode_rmdir(struct inode *dir, struct dentry *dentry,
 			  struct vfsmount *mnt)
 {
-	struct path path = { mnt, dentry };
+	struct path path = { .mnt = mnt, .dentry = dentry };
 	int rc = cs_rmdir_permission(&path);
 	if (rc)
 		return rc;
@@ -547,7 +547,7 @@ static int cs_inode_rmdir(struct inode *dir, struct dentry *dentry,
 static int cs_inode_unlink(struct inode *dir, struct dentry *dentry,
 			   struct vfsmount *mnt)
 {
-	struct path path = { mnt, dentry };
+	struct path path = { .mnt = mnt, .dentry = dentry };
 	int rc = cs_unlink_permission(&path);
 	if (rc)
 		return rc;
@@ -568,7 +568,7 @@ static int cs_inode_unlink(struct inode *dir, struct dentry *dentry,
 static int cs_inode_symlink(struct inode *dir, struct dentry *dentry,
 			    struct vfsmount *mnt, const char *old_name)
 {
-	struct path path = { mnt, dentry };
+	struct path path = { .mnt = mnt, .dentry = dentry };
 	int rc = cs_symlink_permission(&path, old_name);
 	if (rc)
 		return rc;
@@ -593,8 +593,8 @@ static int cs_inode_rename(struct inode *old_dir, struct dentry *old_dentry,
 			   struct dentry *new_dentry,
 			   struct vfsmount *new_mnt)
 {
-	struct path old = { old_mnt, old_dentry };
-	struct path new = { new_mnt, new_dentry };
+	struct path old = { .mnt = old_mnt, .dentry = old_dentry };
+	struct path new = { .mnt = new_mnt, .dentry = new_dentry };
 	int rc = cs_rename_permission(&old, &new);
 	if (rc)
 		return rc;
@@ -619,8 +619,8 @@ static int cs_inode_link(struct dentry *old_dentry, struct vfsmount *old_mnt,
 			 struct inode *dir, struct dentry *new_dentry,
 			 struct vfsmount *new_mnt)
 {
-	struct path old = { old_mnt, old_dentry };
-	struct path new = { new_mnt, new_dentry };
+	struct path old = { .mnt = old_mnt, .dentry = old_dentry };
+	struct path new = { .mnt = new_mnt, .dentry = new_dentry };
 	int rc = cs_link_permission(&old, &new);
 	if (rc)
 		return rc;
@@ -642,7 +642,7 @@ static int cs_inode_link(struct dentry *old_dentry, struct vfsmount *old_mnt,
 static int cs_inode_create(struct inode *dir, struct dentry *dentry,
 			   struct vfsmount *mnt, int mode)
 {
-	struct path path = { mnt, dentry };
+	struct path path = { .mnt = mnt, .dentry = dentry };
 	int rc = cs_mknod_permission(&path, mode, 0);
 	if (rc)
 		return rc;
@@ -1075,7 +1075,7 @@ static int cs_sb_mount(char *dev_name, struct path *path, char *type,
  */
 static int cs_sb_umount(struct vfsmount *mnt, int flags)
 {
-	struct path path = { mnt, mnt->mnt_root };
+	struct path path = { .mnt = mnt, .dentry = mnt->mnt_root };
 	int rc = cs_umount_permission(&path, flags);
 	if (rc)
 		return rc;
