@@ -3,7 +3,7 @@
  *
  * Copyright (C) 2005-2012  NTT DATA CORPORATION
  *
- * Version: 0.1.14   2015/07/21
+ * Version: 0.1.15   2015/08/06
  */
 
 #include "caitsith.h"
@@ -2960,7 +2960,7 @@ static bool cs_file_matches_pattern2(const char *filename,
 				pattern += 2;
 				break;
 			}
-		return false; /* Not matched. */
+			return false; /* Not matched. */
 		case '*':
 		case '@':
 			for (i = 0; i <= filename_end - filename; i++) {
@@ -2979,7 +2979,7 @@ static bool cs_file_matches_pattern2(const char *filename,
 				else
 					break; /* Bad pattern. */
 			}
-		return false; /* Not matched. */
+			return false; /* Not matched. */
 		default:
 			j = 0;
 			c = *pattern;
@@ -3060,69 +3060,49 @@ static bool cs_path_matches_pattern2(const char *f, const char *p)
 {
 	const char *f_delimiter;
 	const char *p_delimiter;
-	char recursive_end;
 	while (*f && *p) {
-		f_delimiter = strchr(f, '/');
+		f_delimiter = strchr(f + 1, '/');
 		if (!f_delimiter)
 			f_delimiter = f + strlen(f);
-		p_delimiter = strchr(p, '/');
+		p_delimiter = strchr(p + 1, '/');
 		if (!p_delimiter)
 			p_delimiter = p + strlen(p);
-		if (*p == '\\') {
-			if (*(p + 1) == '{') {
-				recursive_end = '}';
-				goto recursive;
-			}
-			if (*(p + 1) == '(') {
-				recursive_end = ')';
-				goto recursive;
+		if (*p == '/' && *(p + 1) == '\\') {
+			if (*(p + 2) == '(') {
+				/* Check zero repetition. */
+				if (cs_path_matches_pattern2(f, p_delimiter))
+					return true;
+				/* Check one or more repetition. */
+				goto repetition;
 			}
+			if (*(p + 2) == '{')
+				goto repetition;
 		}
+		if ((*f == '/' || *p == '/') && *f++ != *p++)
+			return false;
 		if (!cs_file_matches_pattern(f, f_delimiter, p, p_delimiter))
 			return false;
 		f = f_delimiter;
-		if (*f)
-			f++;
 		p = p_delimiter;
-		if (*p)
-			p++;
 	}
 	/* Ignore trailing "\*" and "\@" in @pattern. */
-	while (*p == '\\' &&
-	       (*(p + 1) == '*' || *(p + 1) == '@'))
+	while (*p == '\\' && (*(p + 1) == '*' || *(p + 1) == '@'))
 		p += 2;
 	return !*f && !*p;
-recursive:
-	/*
-	 * The "\{" or "\(" pattern is permitted only after '/' character.
-	 * This guarantees that below "*(p - 1)" is safe.
-	 * Also, the "\}" or "\)" pattern is permitted only before '/'
-	 * character so that "\{" + "\}" or "\(" + "\)" pair will not break
-	 * the "\-" operator.
-	 */
-	if (*(p - 1) != '/' || p_delimiter <= p + 3 || *p_delimiter != '/' ||
-	    *(p_delimiter - 1) != recursive_end || *(p_delimiter - 2) != '\\')
-		return false; /* Bad pattern. */
-	if (recursive_end == ')') {
-		/* Check zero repetition. */
-		if (cs_path_matches_pattern2(f, p_delimiter + 1))
-			return true;
-		/* Fall back to one or more repetition. */
-	}
+repetition:
 	do {
 		/* Compare current component with pattern. */
-		if (!cs_file_matches_pattern(f, f_delimiter, p + 2,
+		if (!cs_file_matches_pattern(f + 1, f_delimiter, p + 3,
 					     p_delimiter - 2))
 			break;
 		/* Proceed to next component. */
 		f = f_delimiter;
 		if (!*f)
 			break;
-		f++;
 		/* Continue comparison. */
-		if (cs_path_matches_pattern2(f, p_delimiter + 1))
+		if (cs_path_matches_pattern2(f, p_delimiter))
 			return true;
-		f_delimiter = strchr(f, '/');
+		f_delimiter = strchr(f + 1, '/');
 	} while (f_delimiter);
 	return false; /* Not matched. */
 }
@@ -3165,23 +3145,11 @@ static bool cs_path_matches_pattern(const struct cs_path_info *filename,
 	if (len == pattern->total_len)
 		return !cs_pathcmp(filename, pattern);
 	/* Compare the initial length without patterns. */
-	if (strncmp(f, p, len))
-		return false;
-	f += len;
-	p += len;
-	/* Compare the last component first. */
-	{
-		const char *f2 = strrchr(f, '/');
-		const char *p2 = strrchr(p, '/');
-		if (!f2++)
-			f2 = f;
-		if (!p2++)
-			p2 = p;
-		if (!cs_file_matches_pattern(f2, filename->name
-					     + filename->total_len,
-					     p2, pattern->name
-					     + pattern->total_len))
+	if (len) {
+		if (strncmp(f, p, len))
 			return false;
+		f += len - 1;
+		p += len - 1;
 	}
 	return cs_path_matches_pattern2(f, p);
 }
